# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

SERVICE_ENDPOINTS = {
    "announcement": "https://announcements.{domain}",
    "announcements_preferences": "https://announcements.{domain}",
    "audit": "https://audit.{domain}",
    "auto_scaling": "None",
    "blockstorage": "https://iaas.{domain}",
    "budget": "https://iaas.{domain}",
    "compute": "https://iaas.{domain}",
    "compute_management": "https://iaas.{domain}",
    "container_engine": "https://containerengine.{domain}",
    "database": "https://database.{domain}",
    "dns": "https://dns.{domain}",
    "email": "https://email.{domain}",
    "file_storage": "https://filestorage.{domain}",
    "health_checks": "https://healthchecks.{domain}",
    "identity": "https://identity.{domain}",
    "kms_crypto": "https://kms.{domain}",
    "kms_management": "https://kms.{domain}",
    "kms_vault": "https://kms.{domain}",
    "load_balancer": "https://iaas.{domain}",
    "monitoring": "https://telemetry.{domain}",
    "notification_control_plane": "https://notification.{domain}",
    "notification_data_plane": "https://notification.{domain}",
    "object_storage": "https://objectstorage.{domain}",
    "redirect": "https://waas.{domain}",
    "resource_manager": "https://resourcemanager.{domain}",
    "resource_search": "https://query.{domain}",
    "stream": "https://streams.{domain}",
    "stream_admin": "https://streams.{domain}",
    "virtual_network": "https://iaas.{domain}",
    "waas": "https://waas.{domain}"
}
