# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_container_scan_recipe_compartment_details import ChangeContainerScanRecipeCompartmentDetails
from .change_container_scan_result_compartment_details import ChangeContainerScanResultCompartmentDetails
from .change_container_scan_target_compartment_details import ChangeContainerScanTargetCompartmentDetails
from .change_host_agent_scan_result_compartment_details import ChangeHostAgentScanResultCompartmentDetails
from .change_host_cis_benchmark_scan_result_compartment_details import ChangeHostCisBenchmarkScanResultCompartmentDetails
from .change_host_endpoint_protection_scan_result_compartment_details import ChangeHostEndpointProtectionScanResultCompartmentDetails
from .change_host_port_scan_result_compartment_details import ChangeHostPortScanResultCompartmentDetails
from .change_host_scan_recipe_compartment_details import ChangeHostScanRecipeCompartmentDetails
from .change_host_scan_target_compartment_details import ChangeHostScanTargetCompartmentDetails
from .container_scan_recipe import ContainerScanRecipe
from .container_scan_recipe_summary import ContainerScanRecipeSummary
from .container_scan_recipe_summary_collection import ContainerScanRecipeSummaryCollection
from .container_scan_registry import ContainerScanRegistry
from .container_scan_result import ContainerScanResult
from .container_scan_result_problem import ContainerScanResultProblem
from .container_scan_result_summary import ContainerScanResultSummary
from .container_scan_result_summary_collection import ContainerScanResultSummaryCollection
from .container_scan_settings import ContainerScanSettings
from .container_scan_target import ContainerScanTarget
from .container_scan_target_summary import ContainerScanTargetSummary
from .container_scan_target_summary_collection import ContainerScanTargetSummaryCollection
from .create_container_scan_recipe_details import CreateContainerScanRecipeDetails
from .create_container_scan_registry_details import CreateContainerScanRegistryDetails
from .create_container_scan_target_details import CreateContainerScanTargetDetails
from .create_host_scan_recipe_details import CreateHostScanRecipeDetails
from .create_host_scan_target_details import CreateHostScanTargetDetails
from .create_ocir_container_scan_registry_details import CreateOcirContainerScanRegistryDetails
from .cve_details import CveDetails
from .export_host_agent_scan_result_csv_details import ExportHostAgentScanResultCsvDetails
from .export_host_vulnerability_csv_details import ExportHostVulnerabilityCsvDetails
from .host_agent_scan_result import HostAgentScanResult
from .host_agent_scan_result_problem import HostAgentScanResultProblem
from .host_agent_scan_result_summary import HostAgentScanResultSummary
from .host_agent_scan_result_summary_collection import HostAgentScanResultSummaryCollection
from .host_cis_benchmark_scan_result import HostCisBenchmarkScanResult
from .host_cis_benchmark_scan_result_score import HostCisBenchmarkScanResultScore
from .host_cis_benchmark_scan_result_summary import HostCisBenchmarkScanResultSummary
from .host_cis_benchmark_scan_result_summary_collection import HostCisBenchmarkScanResultSummaryCollection
from .host_cis_benchmark_settings import HostCisBenchmarkSettings
from .host_endpoint_protection_scan_result import HostEndpointProtectionScanResult
from .host_endpoint_protection_scan_result_endpoint_protection import HostEndpointProtectionScanResultEndpointProtection
from .host_endpoint_protection_scan_result_summary import HostEndpointProtectionScanResultSummary
from .host_endpoint_protection_scan_result_summary_collection import HostEndpointProtectionScanResultSummaryCollection
from .host_endpoint_protection_settings import HostEndpointProtectionSettings
from .host_port_scan_result import HostPortScanResult
from .host_port_scan_result_open_port import HostPortScanResultOpenPort
from .host_port_scan_result_summary import HostPortScanResultSummary
from .host_port_scan_result_summary_collection import HostPortScanResultSummaryCollection
from .host_scan_agent_configuration import HostScanAgentConfiguration
from .host_scan_agent_configuration_oci import HostScanAgentConfigurationOCI
from .host_scan_agent_settings import HostScanAgentSettings
from .host_scan_port_settings import HostScanPortSettings
from .host_scan_recipe import HostScanRecipe
from .host_scan_recipe_summary import HostScanRecipeSummary
from .host_scan_recipe_summary_collection import HostScanRecipeSummaryCollection
from .host_scan_target import HostScanTarget
from .host_scan_target_summary import HostScanTargetSummary
from .host_scan_target_summary_collection import HostScanTargetSummaryCollection
from .host_vulnerability import HostVulnerability
from .host_vulnerability_impacted_host_summary import HostVulnerabilityImpactedHostSummary
from .host_vulnerability_impacted_host_summary_collection import HostVulnerabilityImpactedHostSummaryCollection
from .host_vulnerability_summary import HostVulnerabilitySummary
from .host_vulnerability_summary_collection import HostVulnerabilitySummaryCollection
from .ocir_container_scan_registry import OcirContainerScanRegistry
from .schedule import Schedule
from .update_container_scan_recipe_details import UpdateContainerScanRecipeDetails
from .update_container_scan_registry_details import UpdateContainerScanRegistryDetails
from .update_container_scan_target_details import UpdateContainerScanTargetDetails
from .update_host_scan_recipe_details import UpdateHostScanRecipeDetails
from .update_host_scan_target_details import UpdateHostScanTargetDetails
from .update_ocir_container_scan_registry_details import UpdateOcirContainerScanRegistryDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource

# Maps type names to classes for vulnerability_scanning services.
vulnerability_scanning_type_mapping = {
    "ChangeContainerScanRecipeCompartmentDetails": ChangeContainerScanRecipeCompartmentDetails,
    "ChangeContainerScanResultCompartmentDetails": ChangeContainerScanResultCompartmentDetails,
    "ChangeContainerScanTargetCompartmentDetails": ChangeContainerScanTargetCompartmentDetails,
    "ChangeHostAgentScanResultCompartmentDetails": ChangeHostAgentScanResultCompartmentDetails,
    "ChangeHostCisBenchmarkScanResultCompartmentDetails": ChangeHostCisBenchmarkScanResultCompartmentDetails,
    "ChangeHostEndpointProtectionScanResultCompartmentDetails": ChangeHostEndpointProtectionScanResultCompartmentDetails,
    "ChangeHostPortScanResultCompartmentDetails": ChangeHostPortScanResultCompartmentDetails,
    "ChangeHostScanRecipeCompartmentDetails": ChangeHostScanRecipeCompartmentDetails,
    "ChangeHostScanTargetCompartmentDetails": ChangeHostScanTargetCompartmentDetails,
    "ContainerScanRecipe": ContainerScanRecipe,
    "ContainerScanRecipeSummary": ContainerScanRecipeSummary,
    "ContainerScanRecipeSummaryCollection": ContainerScanRecipeSummaryCollection,
    "ContainerScanRegistry": ContainerScanRegistry,
    "ContainerScanResult": ContainerScanResult,
    "ContainerScanResultProblem": ContainerScanResultProblem,
    "ContainerScanResultSummary": ContainerScanResultSummary,
    "ContainerScanResultSummaryCollection": ContainerScanResultSummaryCollection,
    "ContainerScanSettings": ContainerScanSettings,
    "ContainerScanTarget": ContainerScanTarget,
    "ContainerScanTargetSummary": ContainerScanTargetSummary,
    "ContainerScanTargetSummaryCollection": ContainerScanTargetSummaryCollection,
    "CreateContainerScanRecipeDetails": CreateContainerScanRecipeDetails,
    "CreateContainerScanRegistryDetails": CreateContainerScanRegistryDetails,
    "CreateContainerScanTargetDetails": CreateContainerScanTargetDetails,
    "CreateHostScanRecipeDetails": CreateHostScanRecipeDetails,
    "CreateHostScanTargetDetails": CreateHostScanTargetDetails,
    "CreateOcirContainerScanRegistryDetails": CreateOcirContainerScanRegistryDetails,
    "CveDetails": CveDetails,
    "ExportHostAgentScanResultCsvDetails": ExportHostAgentScanResultCsvDetails,
    "ExportHostVulnerabilityCsvDetails": ExportHostVulnerabilityCsvDetails,
    "HostAgentScanResult": HostAgentScanResult,
    "HostAgentScanResultProblem": HostAgentScanResultProblem,
    "HostAgentScanResultSummary": HostAgentScanResultSummary,
    "HostAgentScanResultSummaryCollection": HostAgentScanResultSummaryCollection,
    "HostCisBenchmarkScanResult": HostCisBenchmarkScanResult,
    "HostCisBenchmarkScanResultScore": HostCisBenchmarkScanResultScore,
    "HostCisBenchmarkScanResultSummary": HostCisBenchmarkScanResultSummary,
    "HostCisBenchmarkScanResultSummaryCollection": HostCisBenchmarkScanResultSummaryCollection,
    "HostCisBenchmarkSettings": HostCisBenchmarkSettings,
    "HostEndpointProtectionScanResult": HostEndpointProtectionScanResult,
    "HostEndpointProtectionScanResultEndpointProtection": HostEndpointProtectionScanResultEndpointProtection,
    "HostEndpointProtectionScanResultSummary": HostEndpointProtectionScanResultSummary,
    "HostEndpointProtectionScanResultSummaryCollection": HostEndpointProtectionScanResultSummaryCollection,
    "HostEndpointProtectionSettings": HostEndpointProtectionSettings,
    "HostPortScanResult": HostPortScanResult,
    "HostPortScanResultOpenPort": HostPortScanResultOpenPort,
    "HostPortScanResultSummary": HostPortScanResultSummary,
    "HostPortScanResultSummaryCollection": HostPortScanResultSummaryCollection,
    "HostScanAgentConfiguration": HostScanAgentConfiguration,
    "HostScanAgentConfigurationOCI": HostScanAgentConfigurationOCI,
    "HostScanAgentSettings": HostScanAgentSettings,
    "HostScanPortSettings": HostScanPortSettings,
    "HostScanRecipe": HostScanRecipe,
    "HostScanRecipeSummary": HostScanRecipeSummary,
    "HostScanRecipeSummaryCollection": HostScanRecipeSummaryCollection,
    "HostScanTarget": HostScanTarget,
    "HostScanTargetSummary": HostScanTargetSummary,
    "HostScanTargetSummaryCollection": HostScanTargetSummaryCollection,
    "HostVulnerability": HostVulnerability,
    "HostVulnerabilityImpactedHostSummary": HostVulnerabilityImpactedHostSummary,
    "HostVulnerabilityImpactedHostSummaryCollection": HostVulnerabilityImpactedHostSummaryCollection,
    "HostVulnerabilitySummary": HostVulnerabilitySummary,
    "HostVulnerabilitySummaryCollection": HostVulnerabilitySummaryCollection,
    "OcirContainerScanRegistry": OcirContainerScanRegistry,
    "Schedule": Schedule,
    "UpdateContainerScanRecipeDetails": UpdateContainerScanRecipeDetails,
    "UpdateContainerScanRegistryDetails": UpdateContainerScanRegistryDetails,
    "UpdateContainerScanTargetDetails": UpdateContainerScanTargetDetails,
    "UpdateHostScanRecipeDetails": UpdateHostScanRecipeDetails,
    "UpdateHostScanTargetDetails": UpdateHostScanTargetDetails,
    "UpdateOcirContainerScanRegistryDetails": UpdateOcirContainerScanRegistryDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource
}
