# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

HEADER_NEXT_PAGE = 'opc-next-page'
HEADER_REQUEST_ID = 'opc-request-id'
HEADER_CLIENT_INFO = 'opc-client-info'
HEADER_USER_AGENT = 'user-agent'
